/**************************************************************************/
/* FILE NAME: tpu_id.c                        COPYRIGHT (c) MOTOROLA 2002 */
/* VERSION: 1.0                                   All Rights Reserved     */
/*                                                                        */
/* DESCRIPTION: This file contains the TPU ID functions. This function    */
/* allow you control TPU channels running the ID function.                */
/*========================================================================*/
/* HISTORY           ORIGINAL AUTHOR: Jeff Loeliger                       */
/* REV      AUTHOR      DATE       DESCRIPTION OF CHANGE                  */
/* ---   -----------  ---------    ---------------------                  */
/* 1.0   J. Loeliger  19/Aug/02    Initial version of function.           */
/**************************************************************************/
#include "tpu_id.h"
#include "mpc500_util.h"

/*******************************************************************************
FUNCTION      : tpu_id
PURPOSE       : To initialize a channel aND run the TPU revision ID function.
INPUTS NOTES  : This function has 2 parameters:
                 *tpu - This is a pointer to the TPU3 module to use. It is of
                         type TPU3_tag which is defined in m_tpu3.h
                 channel - This is the channel number of use.
RETURNS NOTES : none
WARNING       : The channel must be stopped before it is reconfigured. The
                function disables the channels but if it was currently
                being serviced it would continue.
*******************************************************************************/
UINT16 tpu_id(struct TPU3_tag *tpu, UINT8 channel)
{
    /* diable channel so it can be configured safely */
    tpu_disable( tpu, channel);
    
    /* select DIO function for channel */
    tpu_func( tpu, channel, TPU_FUNCTION_ID);
    
    /* Enable channel by assigning a priority. */
    tpu_enable(tpu, channel, TPU_PRIORITY_HIGH);

    /* Initialize channel */
    tpu_hsr(tpu, channel, TPU_ID_GET_REV);
    
    /* wait for TPU to put rev in parameter RAM */
    tpu_ready(tpu, channel);
    
    /* return TPU revision number */
    return(tpu->PARM.R[channel][TPU_ID_REV]);
    
}


 
/*********************************************************************
 *
 * Copyright:
 *	MOTOROLA, INC. All Rights Reserved.  
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of Motorola, Inc. This 
 *  software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, MOTOROLA 
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED, INCLUDING 
 *  IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 *  PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH REGARD TO THE 
 *  SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF) AND ANY 
 *  ACCOMPANYING WRITTEN MATERIALS.
 * 
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL MOTOROLA BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING 
 *  WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS 
 *  INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY
 *  LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.   
 * 
 *  Motorola assumes no responsibility for the maintenance and support
 *  of this software
 ********************************************************************/

