/**************************************************************************/
/* FILE NAME: tpu_id_example1.c              COPYRIGHT (c) MOTOROLA 2002 */
/* VERSION: 1.0                                   All Rights Reserved     */
/*                                                                        */
/* DESCRIPTION: This sample program shows a simple example of a program   */
/* that uses the id API to get the revision of the TPU microcode.         */
/* The program is targeted for the MPC555 but should work on any MPC500   */
/* device with a TPU. For other devices the setup routines will also need */
/* to be changed.                                                         */
/*========================================================================*/
/* HISTORY           ORIGINAL AUTHOR: Jeff Loeliger                       */
/* REV      AUTHOR      DATE       DESCRIPTION OF CHANGE                  */
/* ---   -----------  ---------    ---------------------                  */
/* 1.0   J. Loeliger  30/Aug/02    Initial version of function.           */
/**************************************************************************/

#include "mpc555.h"     /* Define all of the MPC555 registers, this needs to */
                        /* changed if other MPC500 devices are used.         */
#include "mpc500.c"     /* Configuration routines for MPC555 EVB, will need */
                        /* to be changed if other hardware is used.         */
#include "mpc500_util.h"    /* Utility routines for using MPC500 devices */
#include "tpu_id.h"    /* TPU ID functions */

UINT16 tpu3_rev;                  /* TPU3 revision number     */
UINT8  i;

void main ()
{
     struct TPU3_tag *tpua = &TPU_A;   /* pointer for TPU routines */
   
     setup_mpc500(40);       /*Setup device and programm PLL to 40MHz*/	

    /* the ID function is in back 1 so configure the TPU3 to use bank 1 */
    /* this is a write once field.                                      */
    TPU_A.TPUMCR2.B.ETBANK = 1;

    /* make sure ETBANK is set to 1 or the wrong function will be used */
    if (TPU_A.TPUMCR2.B.ETBANK != 1)
        while(1);            /* ERROR could not change bank */
                             /* field must have already been written */
        
    /* get mask number of TPU3 microcode */
    tpu3_rev = tpu_id(tpua, 0);

    /* Normally the TPU3 uses the entry table in bank 0 so after getting */
    /* the revision from the ID function in bank 1 use the soft reset    */
    /* function to get back to bank 0. The ETBANK field is write once    */
    /* so after configuring it to 1 a soft reset number be used.         */
    
    /* the STOP bit must be set before the soft reset feature is used.   */
    TPU_A.TPUMCR.B.STOP = 1;
    TPU_A.TPUMCR2.B.SOFTRST = 1;
    
    /* the TPU3 is now held in reset. */
    /* the soft reset bit must be asserted for at least 9 clock cycles */
    for(i=0;i<10;i++);    /* should delay more than 9 clock cycles */
    
    /* bring TPU3 out of reset and enable it again. */
    TPU_A.TPUMCR2.B.SOFTRST = 0;
    TPU_A.TPUMCR.B.STOP = 0;
}

/*********************************************************************
 *
 * Copyright:
 *	MOTOROLA, INC. All Rights Reserved.  
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of Motorola, Inc. This 
 *  software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, MOTOROLA 
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED, INCLUDING 
 *  IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 *  PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH REGARD TO THE 
 *  SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF) AND ANY 
 *  ACCOMPANYING WRITTEN MATERIALS.
 * 
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL MOTOROLA BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING 
 *  WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS 
 *  INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY
 *  LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.   
 * 
 *  Motorola assumes no responsibility for the maintenance and support
 *  of this software
 ********************************************************************/

